menu
self package
documentation
self.dart
self.dart
dark_mode
light_mode
self
library
Classes
Self
SelfLogger
Create a class that implements
SelfLogger
to allow the installer and launcher to log to your existing log system. Implement each method passing the details to your existing logger.
self package
documentation
self.dart
self
package
Libraries
self
self library